/**
 * @file
 * quartiers_de_demain behaviors.
 */
 (function (Drupal) {

    'use strict';
  
    Drupal.behaviors.quartiers_de_demain = {
      attach: function (context, settings) {
        console.log('It works!');
      }
    };
  } (Drupal));


  //////// start header ////////////
  document.addEventListener('DOMContentLoaded', function() {

    const header = document.querySelector('header');
    const logo = document.querySelector('#block-quartiers-de-demain-logoquartiersdedemain > div:nth-child(1) > div:nth-child(1) > a:nth-child(1) > svg:nth-child(1)');
    const headerNavContainer = document.querySelector('.header_nav_container');
    const isFirstLoad = !performance.getEntriesByType("navigation")[0].type.includes('back_forward');
    const isTargetPath = window.location.pathname === '/';

    // Fonction pour démarrer l'animation du logo SVG
    function startLogoAnimation() {
      logo.classList.add('animated');
    }
  
    // Fonction pour arrêter l'animation du logo SVG
    function stopLogoAnimation() {
      logo.classList.remove('animated');
    }
  
    // Vérifier si le header a la classe header--collapse
    function checkHeaderCollapse() {
      if (header.classList.contains('header--collapsed')) {
        stopLogoAnimation();
      } else if (header.classList.contains('header--collapsed-already'))  {
          stopLogoAnimation();
        } else {
        startLogoAnimation();
      }

    }
  
    // Appeler la fonction au chargement initial
    checkHeaderCollapse();
  
    // Observer les changements de classe sur le header
    const observer = new MutationObserver(function(mutations) {
      mutations.forEach(function(mutation) {
        if (mutation.attributeName === 'class') {
          checkHeaderCollapse();
        }
      });
    });
    observer.observe(header, { attributes: true });
 

    // Si ce n'est pas la première charge ou si le chemin n'est pas le chemin cible, ajouter la classe immédiatement
    if (!isFirstLoad || !isTargetPath) {
      header.classList.add('header--collapsed-already');
      // logo.classList.remove('animated');
      stopLogoAnimation();
    } else {
      // Sinon, appliquer la transition après un délai
      setTimeout(() => {
          header.classList.add('header--collapsed');
      }, 5000);
    }

    //////////////////////////////////////

    let lastScrollTop = 0;
    let threshold = 100; // Change this value as needed
    let isHidden = false;
  
    function slideOut() {
      headerNavContainer.animate([
        { transform: 'translateX(0)' },
        { transform: 'translateX(-100%)' }
      ], {
        duration: 300,
        fill: 'forwards'
      });
      isHidden = true;
    }
  
    function slideIn() {
      headerNavContainer.animate([
        { transform: 'translateX(-100%)' },
        { transform: 'translateX(0)' }
      ], {
        duration: 300,
        fill: 'forwards'
      });
      isHidden = false;
    }
    
    function slideDown() {
      // headerNavContainer.style.display = 'block';
      headerNavContainer.animate([
        { transform: 'translateY(0%)' },
        { transform: 'translateY(+100%)' }
      ], {
        duration: 300,
        fill: 'forwards'
      });
      isHidden = false;
    }
  
    function slideUp() {
      headerNavContainer.animate([
        { transform: 'translateY(100%)' },
        { transform: 'translateY(0%)' }
      ], {
        duration: 300,
        fill: 'forwards'
      }).onfinish = function() {
        // headerNavContainer.style.display = 'none';
      };
      isHidden = true;
    }
      // Fonction pour ajuster la hauteur du header lors du défilement
      function adjustHeaderHeight() {
        if (window.scrollY > 0) {
          header.classList.add('shrink');
        } else {
          header.classList.remove('shrink');
        }
      }

    function handleScroll() {
      let scrollTop = window.pageYOffset || document.documentElement.scrollTop;
      const isMobile = window.innerWidth < 811;

      if (scrollTop > threshold && !isHidden) {
        if (isMobile) {
          slideUp();
        } else {
          slideOut();
        }
      } else if (scrollTop <= threshold && isHidden) {
        if (isMobile) {
          slideDown();
        } else {
          slideIn();
        }
      }
  
  
      lastScrollTop = scrollTop <= 0 ? 0 : scrollTop; // For Mobile or negative scrolling
    }
  
    function handleTouchAndMouseEnter() {
      if (isHidden) {
        if (window.innerWidth < 811) {
          slideDown();
        } else {
          slideIn();
        }
      }
    }
  
    function handleTouchAndMouseLeave() {
      if (lastScrollTop > threshold && !isHidden) {
        if (window.innerWidth < 811) {
          slideUp();
        } else {
          slideOut();
        }
      }
    }
  
    window.addEventListener('scroll', handleScroll);
    window.addEventListener('scroll', adjustHeaderHeight);
  
    // Mouse events for desktop
    header.addEventListener('mouseenter', handleTouchAndMouseEnter);
    header.addEventListener('mouseleave', handleTouchAndMouseLeave);
  
    // Touch events for tablets and mobile devices
    header.addEventListener('touchstart', handleTouchAndMouseEnter);
    header.addEventListener('touchend', handleTouchAndMouseLeave);
  
    // Initial check to see if we're at the top of the page
    if (window.pageYOffset <= threshold) {
      if (window.innerWidth < 811) {
        slideDown();
      } else { 
        slideIn();
      } 
    } else {
      if (window.innerWidth < 811) {
        slideUp();
      } else {
        slideIn();
      }
    }
  
  });

//////// end header ////////////
  


//// ancre dans texte au click paragraphe correspondant arrive en dessous du header 


(function($, window) {
  var adjustAnchor = function() {
      var $anchor = $('.sidebar_first_container'),
              fixedElementHeight = 500;
      if ($anchor.length > 0) {
          $('html, body').stop().animate({scrollTop: $anchor.offset().top - fixedElementHeight }, 0);
      }
  };

  $(window).on('hashchange', function() {
      adjustAnchor();
  });


  ////////////////////////  start script smooth apparition des textes /////////////////

  function scrollReaveal(){

    const nodes = {
      logo : document.querySelectorAll('#logo-animated-container'),
      chapeau :  document.querySelectorAll('.field_body'),
      paragraph: document.querySelectorAll('.field_field_textes .paragraph--type--static-parts'),
      enjeux : document.querySelectorAll('.field_field_textes .paragraph--type--static-parts .enjeux'),
      // mapHome : document.querySelectorAll('.field_field_map_block #block-sitesmapblock'),
      // mapSite : document.querySelectorAll('#sites-map-container'),
      lienDoc : document.querySelectorAll('.field_field_documents'),
      lienURL : document.querySelectorAll('.field_field_liens_site'),
    }

    const showUp = {
        origin: 'bottom',
        delay: 100,
        duration: 1000,
        distance: '50px',
        easing: 'cubic-bezier(0.5, 0, 0, 1)'
    }

    const Show = {
      delay: 100,
      duration: 600,
      easing: 'cubic-bezier(0.5, 0, 0, 1)'
    }

    console.log(nodes);

    ScrollReveal().reveal(nodes.logo, Show);
    ScrollReveal().reveal(nodes.chapeau, showUp);
    ScrollReveal().reveal(nodes.paragraph, showUp);
    ScrollReveal().reveal(nodes.enjeux, showUp);
    // ScrollReveal().reveal(nodes.mapHome, showUp);
    // ScrollReveal().reveal(nodes.mapSite, showUp);
    ScrollReveal().reveal(nodes.lienDoc, showUp);
    ScrollReveal().reveal(nodes.lienURL, showUp);

  }


  $( document ).ready(function() {
    scrollReaveal();
  });

  ////////////////////////  end script smooth apparition des textes /////////////////

  // //////////////////// start Timeline script ///////////////////////

    // Update month field to only show the first 3 letters
    document.querySelectorAll('.paragraph--type--phase-deroulement').forEach(function(paragraph) {
      const monthField = paragraph.querySelector('.field_field_date_de_moi div:nth-of-type(2)');
      if (monthField) {
        const monthText = monthField.textContent.trim();
        if (monthText === "juillet") {
          monthField.textContent = monthText.slice(0, 4);
          monthField.classList.add('after');
        } else if (monthText === "juin") {
          monthField.textContent = monthText.slice(0, 4);
        } else if (monthText.length > 3) {
          monthField.textContent = monthText.slice(0, 3);
          monthField.classList.add('after');
        }
      }
    });
  
    // Fonction pour ajouter ou retirer la classe .only
    function updateDateClasses() {
      document.querySelectorAll('.paragraph--type--phase-deroulement .date').forEach(function(dateElement) {
        const date2Element = dateElement.querySelector('.date2');
        const yearElement = dateElement.querySelector('.field_field_date_de_annee');
  
        if (date2Element && !date2Element.textContent.trim()) {
          if (yearElement) {
            yearElement.classList.add('only');
          }
        } else {
          if (yearElement) {
            yearElement.classList.remove('only');
          }
        }
      });
    }
  
    // Exécuter la fonction une première fois pour le contenu déjà présent
    updateDateClasses();
  
    // MutationObserver pour surveiller les changements dans le DOM
    const observer = new MutationObserver(function(mutationsList, observer) {
      for(let mutation of mutationsList) {
        if (mutation.type === 'childList') {
          updateDateClasses();
        }
      }
    });


  //   ////////////////////// start  calendrier home   /////////////////////////////////
    $(document).ready(function(){
      $('.__timeline-content').slick({
        slidesToShow: 3,
        slidesToScroll: 1,
        dots: false,
        arrows: true,
        centerMode: false,
        draggable: true,
        infinite: false,
        responsive: [
          {
            breakpoint: 810,
            settings: {
              slidesToShow: 1,
              adaptiveHeight: false,
              arrows: true,
              draggable: true,
              centerMode: false,
              infinite: false,
            }
          }]
      });
      console.log('salut slick calendrier');
    
      });
    
  //////////////////////// end   calendrier home   /////////////////////////////////
  
  

  //////////////////////// end Timeline script /////////////////////////////////////////////

  ///////////////////  caracteres  body actus/////////////////////////

  document.addEventListener('DOMContentLoaded', function() {
    // Maximum number of characters to display
    const maxChars = 140; // Adjust this value as needed
  
    document.querySelectorAll('#actus-caroussel .node-type-actualite .field_body p').forEach(function(paragraph) {
      let text = paragraph.textContent.trim();
      if (text.length > maxChars) {
        let truncatedText = text.slice(0, maxChars) + '...';
        paragraph.textContent = truncatedText;
      }
    });
  });
  

 //////////// start slideshow home  ////////////////////////// 



  $(document).ready(function(){
      let actuview = $('.content-actus .view ')
      if (actuview) {
        actuview.slick({
          slidesToShow: 3,
          // slidesToScroll: 1,
          dots: false,
          arrows: true,
          // centerMode: true,
          adaptiveHeight: false,
          autoplay: false,
          // autoplaySpeed: 1500,
          // infinite: true,
          // centerPadding: '100px',
          responsive: [
            {
              breakpoint: 810,
              settings: {
                slidesToShow: 1,
                // slidesToScroll: 1,
                adaptiveHeight: false,
                arrows: true,
                draggable: true,
                // centerMode: true,
                // centerPadding: '100px',
                autoplay: false,
                // autoplaySpeed: 2000,
              }
            }]
        });
        console.log('salut slick home');
        
      }
      $('.slick-carousel').slick({
        lazyLoad: 'progressive', // Option 'ondemand' ou 'progressive'
      });

  });




  $(document).ready(function () {
    let diapohome = $('.config_pages--type--diaporama-home .diaporama');

    if (diapohome.length) {
        // Initialisation de Slick
        diapohome.slick({
            slidesToShow: 1,
            dots: false,
            arrows: false,
            // centerMode: true,
            adaptiveHeight: false,
            autoplay: true,  // Activer l'autoplay
            autoplaySpeed: 4000,  // Changement de slide toutes les 4 secondes
            // infinite: true,
            pauseOnHover: false,  // Ne pas arrêter l'autoplay lors du survol
            pauseOnFocus: false,
            responsive: [
                {
                    breakpoint: 810,
                    settings: {
                        slidesToShow: 1,
                        adaptiveHeight: false,
                        arrows: false,
                        draggable: true,
                        centerMode: false,
                    }
                }]
        });

  }
});

 ////////////  end slideshow home  ////////////////////////// 

//////////////// start lightbox galerie image page site////////////////////////

// Sélection des images et de leurs légendes dans la galerie
let images = document.querySelectorAll('.paragraph--type--site-diapo .lightbox-trigger');
let currentIndex;

// Création de la lightbox et de ses éléments
const lightbox = document.createElement('div');
lightbox.id = 'lightbox';
lightbox.classList.add('lightbox');
document.body.appendChild(lightbox);

const img = document.createElement('img');
lightbox.appendChild(img);

// Élément pour afficher la légende
const caption = document.createElement('p');
caption.classList.add('caption');
lightbox.appendChild(caption);

const closeBtn = document.createElement('span');
closeBtn.classList.add('close');
closeBtn.innerHTML = '&times;';
lightbox.appendChild(closeBtn);

const prevBtn = document.createElement('a');
prevBtn.classList.add('prev');
prevBtn.innerHTML = '&#10094;';
lightbox.appendChild(prevBtn);

const nextBtn = document.createElement('a');
nextBtn.classList.add('next');
nextBtn.innerHTML = '&#10095;';
lightbox.appendChild(nextBtn);

// Fonction pour afficher l'image et la légende à l'index donné
function showImage(index) {
  if (index < 0) index = images.length - 1;
  if (index >= images.length) index = 0;
  currentIndex = index;

  // Mettre à jour l'image
  img.src = images[currentIndex].getAttribute('src');

  // Récupérer la légende associée (le paragraphe dans blockquote suivant l'image)
  const captionText = images[currentIndex]
    .closest('.cadre-img-zoom')
    .nextElementSibling.querySelector('.image-field-caption p')
    .textContent;
    
  caption.textContent = captionText || ''; // Affiche la légende ou une chaîne vide si elle est absente
  lightbox.style.display = 'flex';
}

// Événements de clic sur chaque image pour ouvrir le lightbox avec la légende
images.forEach((image, index) => {
  image.addEventListener('click', () => {
    showImage(index);
  });
});

// Fermer le lightbox
closeBtn.addEventListener('click', () => {
  lightbox.style.display = 'none';
});

// Navigation pour images précédente et suivante
prevBtn.addEventListener('click', (e) => {
  e.stopPropagation();
  showImage(currentIndex - 1);
});

nextBtn.addEventListener('click', (e) => {
  e.stopPropagation();
  showImage(currentIndex + 1);
});

// Fermer le lightbox en cliquant en dehors de l'image
lightbox.addEventListener('click', (e) => {
  if (e.target === lightbox) {
    lightbox.style.display = 'none';
  }
});

// Ajout des contrôles clavier (Échap, flèches gauche/droite)
document.addEventListener('keydown', (e) => {
  if (lightbox.style.display === 'flex') {
    if (e.key === 'Escape') {
      lightbox.style.display = 'none';
    } else if (e.key === 'ArrowLeft') {
      showImage(currentIndex - 1);
    } else if (e.key === 'ArrowRight') {
      showImage(currentIndex + 1);
    }
  }
});


//////////////// end lightbox galerie image page site////////////////////////

  

//////////////////// start wrapper views-row  lessites /////////////////////////
document.addEventListener("DOMContentLoaded", function() {
  // Sélectionne le conteneur principal avec l'ID 'lessites'
  const container = document.getElementById("lessites");

  // Vérifie si le conteneur existe pour éviter toute erreur sur d'autres pages
  if (container) {
    // Sélectionne l'élément 'view' à l'intérieur de '.views-element-container'
    const viewContainer = container.querySelector(".views-element-container .view");

    // Vérifie si 'viewContainer' existe pour éviter les erreurs
    if (viewContainer) {
      // Crée une div englobante pour tous les éléments 'views-row'
      const wrapperDiv = document.createElement("div");
      wrapperDiv.classList.add("views-row-wrapper"); // ajoute une classe pour faciliter le style CSS

      // Déplace tous les éléments 'views-row' dans la nouvelle div
      const viewsRows = viewContainer.querySelectorAll(".views-row");
      viewsRows.forEach(row => wrapperDiv.appendChild(row));

      // Ajoute la div englobante dans le 'viewContainer'
      viewContainer.appendChild(wrapperDiv);
    }
  }
});


//////////////////// end wrapper views-row  lessites /////////////////////////



////////////////////  start div infos site  ////////////////////////

// Vérifie si la page a la classe 'node-type-site' dans le <body>
if (document.body.classList.contains('node-type-site')) {
  // Sélectionne le conteneur principal
  const blockRegion = document.querySelector('.block-region-second');

  // Liste des classes spécifiques à cibler
  const fieldClasses = [
      '.field_field_region',
      '.field_field_nom_du_qpv_nb_d_hab',
      '.field_field_departement_s',
      '.field_field_programme_de_l_etat',
      '.field_field_porteur_s_de_site',
      '.field_field_nom_de_la_commune_nb_d_hab'
  ];

  // Sélectionne les div parents de chacun des champs listés
  const elementsToWrap = [];
  fieldClasses.forEach(className => {
      const fieldElement = blockRegion.querySelector(className);
      if (fieldElement) {
          // Ajoute le parent du champ au tableau si trouvé
          elementsToWrap.push(fieldElement.parentElement);
      }
  });

  // Vérifie que des éléments ont été trouvés
  if (elementsToWrap.length > 0) {
      // Crée le conteneur avec la classe 'infos'
      const infosContainer = document.createElement('div');
      infosContainer.className = 'infos';

      // Insère le conteneur `.infos` avant le premier élément ciblé
      const firstElement = elementsToWrap[0];
      blockRegion.insertBefore(infosContainer, firstElement);

      // Déplace chaque élément dans le conteneur `.infos`
      elementsToWrap.forEach(element => infosContainer.appendChild(element));
  }
}
////////////////////  end div infos site  ////////////////////////

document.addEventListener("DOMContentLoaded", function() {
  // Sélectionner les éléments à déplacer
  const documentsField = document.querySelector(".field_field_documents");
  const liensSiteField = document.querySelector(".field_field_liens_site");
  
  // Sélectionner la destination
  const thirdRegion = document.querySelector(".block-region-third > div");

  // Créer une nouvelle div pour englober les éléments déplacés
  const wrapperDiv = document.createElement("div");
  wrapperDiv.classList.add("documents-liens-wrapper");

  // Déplacer les éléments dans la nouvelle div
  if (documentsField && liensSiteField && thirdRegion) {
      wrapperDiv.appendChild(documentsField);
      wrapperDiv.appendChild(liensSiteField);

      // Ajouter la nouvelle div dans la destination
      thirdRegion.appendChild(wrapperDiv);
  }
});
document.addEventListener("DOMContentLoaded", function() {
  // Sélectionner les éléments pertinents
  const documentsLiensWrapper = document.querySelector(".documents-liens-wrapper");
  const blockRegionThird = document.querySelector(".block-region-third");

  // Vérifier que les éléments existent avant de les manipuler
  if (documentsLiensWrapper && blockRegionThird) {
      // Déplacer .documents-liens-wrapper en dehors du div contenant les boutons prev/next
      blockRegionThird.appendChild(documentsLiensWrapper);
  }
});


document.addEventListener("DOMContentLoaded", function () {
  // Fonction pour déplacer le bloc en fonction de la taille de l'écran
  function moveLanguageSwitcher() {
    const languageSwitcher = document.getElementById("block-quartiers-de-demain-selecteurdelangue");
    const navContainer = document.querySelector(".header_nav_container");

    if (window.innerWidth <= 810) { // Si écran téléphone
      if (languageSwitcher && navContainer && !navContainer.contains(languageSwitcher)) {
        navContainer.appendChild(languageSwitcher); // Déplace le bloc dans header_nav_container
      }
    } else { // Si écran non téléphone
      const headerRightContainer = document.querySelector(".header_right_container");
      if (languageSwitcher && headerRightContainer && !headerRightContainer.contains(languageSwitcher)) {
        headerRightContainer.appendChild(languageSwitcher); // Remet le bloc dans sa position initiale
      }
    }
  }

  // Déclencher au chargement et au redimensionnement
  moveLanguageSwitcher();
  window.addEventListener("resize", moveLanguageSwitcher);
});


})(jQuery, window);


